Calculation

Struct Calculation 

pub struct Calculation {
    pub num1: f64,
    pub num2: f64,
    pub operation: Operations,
}
Calculation struct used for everything.

Fields

num1: f64num2: f64operation: Operations

Implementations

Source

impl Calculation

pub fn from_string(input: &str) -> Result<Self, &str>

Converts a string to a calculation struct, assumes standard notation

Example
let mut calc = calculator::Calculation::from_string("3 + 6").unwrap();

Now you can use any of the functions from calculator!

Panics

Never

Errors

Returns error when input isn’t long enough or a conversion error occurs

Safety

This fn is safe AF.

pub fn from_rpn(input: &str) -> Result<Self, &str>

pub fn new(num1: f64, num2: f64, op: char) -> Result<Self, &'static str>

pub fn calculate_result(&self) -> f64